﻿using System;
using Windows.Foundation.Metadata;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Animation;
using Windows.UI.Xaml.Navigation;

namespace TestProject
{
    /// <summary>
    /// 리스트 페이지
    /// </summary>
    public sealed partial class ListPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 커스텀 항목
        /// </summary>
        private CustomItem customItem;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - ListPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public ListPage()
        {
            this.InitializeComponent();

            NavigationCacheMode = NavigationCacheMode.Enabled;

            this.listView.ItemsSource = CustomItem.GetList();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 리스트 뷰 로드시 처리하기 - listView_Loaded(sender, e)

        /// <summary>
        /// 리스트 뷰 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private async void listView_Loaded(object sender, RoutedEventArgs e)
        {
            if(this.customItem != null)
            {
                this.listView.ScrollIntoView(this.customItem, ScrollIntoViewAlignment.Default);

                this.listView.UpdateLayout();

                ConnectedAnimation animation = ConnectedAnimationService.GetForCurrentView().GetAnimation("BackwardAnimation");

                if(animation != null)
                {
                    if(ApiInformation.IsApiContractPresent("Windows.Foundation.UniversalApiContract", 7))
                    {
                        animation.Configuration = new DirectConnectedAnimationConfiguration();
                    }

                    await this.listView.TryStartConnectedAnimationAsync(animation, this.customItem, "image");
                }
            }
        }

        #endregion
        #region 리스트 뷰 항목 클릭시 처리하기 - listView_ItemClick(sender, e)

        /// <summary>
        /// 리스트 뷰 항목 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void listView_ItemClick(object sender, ItemClickEventArgs e)
        {
            if(this.listView.ContainerFromItem(e.ClickedItem) is ListViewItem listViewitem)
            {
                this.customItem = listViewitem.Content as CustomItem;

                ConnectedAnimation animation = this.listView.PrepareConnectedAnimation("ForwardAnimation", this.customItem, "image");
            }

            Frame.Navigate(typeof(DetailPage), this.customItem, new SuppressNavigationTransitionInfo());
        }

        #endregion
    }
}